@@ -3,10 +3,10 @@ GND <- function(nodiv_result, node = NULL)
 {
   if(!inherits(nodiv_result, "nodiv_result"))
     stop("object must be of type nodiv_result")
-  if(is.null(node)) node <- TRUE else node <- identify_node(node, nodiv_result)
+  if(is.null(node)) node <- nodenumbers(nodiv_result) else node <- identify_node(node, nodiv_result)
   ret <- nodiv_result$GND[node - Nspecies(nodiv_result)]
   names(ret) <- nodenumbers(nodiv_result)
-  return()
+  return(ret)
 }
 
 print.nodiv_result <- function(x, printlen = 4, ...)
